@@ -19,4 +19,12 @@ def md5_checksum(filepath):
     md5.update(fp.read().encode('base64'))
     checksum = md5.hexdigest()
     fp.close()
-    return checksum
\ No newline at end of file
+    return checksum
+
+def get_config_option(config, section, option=None, boolean=False, fallback=None):
+    if config.has_section(section):
+        if option is None:
+            return config.items(section)
+        elif config.has_option(section, option):
+            return config.get(section, option) if boolean == False else config.getboolean(section, option)
+    return fallback
\ No newline at end of file
